pub fn last_calibration_result() -> Option<CalibrationResult>Expand description
Get the last calibration result.
This can be used to know if any previously persisted calibration data is outdated/invalid and needs to get updated.
pub fn last_calibration_result() -> Option<CalibrationResult>Get the last calibration result.
This can be used to know if any previously persisted calibration data is outdated/invalid and needs to get updated.